# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import run_service_pb2 as grid_dot_v1_dot_run__service__pb2


class RunServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateRun = channel.unary_unary(
            '/grid.v1.RunService/CreateRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.FromString,
        )
        self.GetRun = channel.unary_unary(
            '/grid.v1.RunService/GetRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.FromString,
        )
        self.ListRuns = channel.unary_unary(
            '/grid.v1.RunService/ListRuns',
            request_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.FromString,
        )
        self.UpdateRun = channel.unary_unary(
            '/grid.v1.RunService/UpdateRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.FromString,
        )
        self.UpdateRunStatus = channel.unary_unary(
            '/grid.v1.RunService/UpdateRunStatus',
            request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.FromString,
        )
        self.DeleteRun = channel.unary_unary(
            '/grid.v1.RunService/DeleteRun',
            request_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.FromString,
        )
        self.WatchRuns = channel.unary_stream(
            '/grid.v1.RunService/WatchRuns',
            request_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.FromString,
        )


class RunServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRuns(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRunStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRun(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchRuns(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.SerializeToString,
        ),
        'GetRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.SerializeToString,
        ),
        'ListRuns':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListRuns,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.SerializeToString,
        ),
        'UpdateRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.SerializeToString,
        ),
        'UpdateRunStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateRunStatus,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.SerializeToString,
        ),
        'DeleteRun':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteRun,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.SerializeToString,
        ),
        'WatchRuns':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchRuns,
            request_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.FromString,
            response_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.RunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



from datetime import datetime
from typing import Any, Dict, Iterable, NamedTuple, Optional

from grid.sdk import env
from grid.sdk._gql.queries import (
    cancel_experiment,
    experiment_archived_build_logs,
    experiment_archived_logs,
    experiment_live_build_logs,
    experiment_live_logs,
    get_experiment_details_gql,
    get_experiment_status_gql,
)
from grid.sdk.user import User


class ExperimentName(NamedTuple):
    name: str
    username: Optional[str]

    @classmethod
    def from_external_format(cls, name: str):
        """User can pass experiments as username:experiment_name to fetch other users experiments.
        """
        username = None
        split = name.split(":")
        if len(split) > 2:
            raise ValueError(f"Error while parsing {name}. Use the format <username>:<experiment-name>")
        elif len(split) == 2:
            username = split[0]
            name = split[1]

        return cls(name=name, username=username)


class Experiment:
    _name: str
    _exp_id: str
    _last_status: str
    _desired_state: str

    _created_at: datetime
    _started_running_at: datetime
    _finished_at: datetime

    _github_id: str
    _commit_sha: str
    _invocation_commands: str
    _parameters: Dict[str, Any]
    _user: User

    def __init__(
        self,
        name: str,
        exp_id: str,
        last_status: str,
        desired_state: str,
        created_at: datetime,
        started_running_at: datetime,
        finished_at: datetime,
        github_id: str,
        commit_sha: str,
        invocation_commands: str,
        parameters: Dict[str, Any],
        user: User,
    ):
        self._exp_id = exp_id
        self._name = name
        self._last_status = last_status
        self._desired_state = desired_state
        self._created_at = created_at
        self._started_running_at = started_running_at
        self._finished_at = finished_at
        self._github_id = github_id
        self._commit_sha = commit_sha
        self._invocation_commands = invocation_commands
        self._parameters = parameters
        self._user = user

    @classmethod
    def _init_via_gql_query(cls, exp_id: str):
        config = get_experiment_details_gql(experiment_id=exp_id)
        _parameters = {}
        for param in config['parameters']:
            name, value = param['name'], param['value']
            if name == value:
                # not a true parameter, just part of the setup.
                continue
            _parameters[name] = value

        return cls(
            exp_id=config['experimentId'],
            name=config['name'],
            user=User(
                user_id=config['userDetails']['id'],
                username=config['userDetails']['username'],
                first_name=config['userDetails']['firstName'],
                last_name=config['userDetails']['lastName'],
            ),
            last_status=config['status'].upper(),
            desired_state=config['desiredState'].upper(),
            github_id=config['githubId'],
            commit_sha=config['commitSha'],
            created_at=datetime.fromisoformat(config['createdAt']),
            started_running_at=datetime.fromisoformat(config['startedRunningAt']),
            finished_at=datetime.fromisoformat(config['finishedAt']),
            invocation_commands=config['invocationCommands'],
            parameters=_parameters
        )

    def __repr__(self):
        return (
            f"{self.__class__.__name__}(, \n"
            f"    name={self.name}, \n"
            f"    status={self.status()}, \n"
            f"    project={self.github_id} @ {self.commit_sha}, \n"
            f"    parameters={self.parameters}, \n"
            f"    invocation_command={self.invocation_commands}, \n"
            f"    user={self.user.username}, \n"
            f"    created_at={self.created_at}, \n"
            f"    started_running_at={self.started_running_at}, \n"
            f"    finished_at={self.finished_at}, \n"
            f")"
        )

    @property
    def id(self) -> str:
        """Id of the experiment
        """
        return self._exp_id

    @property
    def name(self) -> str:
        """The name of this experiment. Typically ``run-name + -expN``.
        """
        return self._name

    def _update_status(self):
        current = get_experiment_status_gql(experiment_id=self.id)
        self._last_status = current['status']
        self._desired_state = current['desiredState']
        self._created_at = datetime.fromisoformat(current['createdAt'])
        self._started_running_at = datetime.fromisoformat(current['startedRunningAt'])
        self._finished_at = datetime.fromisoformat(current['finishedAt'])

    def status(self) -> str:
        """Queries the grid platform to retrieve the current state of this experiment.

        Returns
        -------
        str
            one of "QUEUED", "RUNNING", "CANCELLED", "FAILED", "COMPLETED"
        """
        # perform query once and cache results
        if self._last_status not in env.TERMINAL_STATES:
            self._update_status()

        return self._last_status

    @property
    def created_at(self) -> datetime:
        """Datetime which the experiment was first scheduled to start.
        """
        return self._created_at

    @property
    def started_running_at(self) -> datetime:
        """Datetime when the experiment actually started running.
        """
        if self._last_status not in env.TERMINAL_STATES:
            self._update_status()
        return self._started_running_at

    @property
    def finished_at(self) -> datetime:
        """Datetime when the experiment finished running (either completed, failed, or cancelled).
        """
        if self._last_status not in env.TERMINAL_STATES:
            self._update_status()
        return self._finished_at

    @property
    def invocation_commands(self) -> str:
        """Command which was used to kick off the script's job.
        """
        return self._invocation_commands

    @property
    def parameters(self) -> dict:
        """Dict of hyperparameter names/values which this experiment used
        """
        return self._parameters

    @property
    def user(self) -> User:
        """User who launched this experiment.
        """
        return self._user

    @property
    def github_id(self) -> str:
        """Github project which the code in this experiment runs from.
        """
        return self._github_id

    @property
    def commit_sha(self) -> str:
        """Commit sha which of a git repo which the code runs from.
        """
        return self._commit_sha

    def cancel(self) -> str:
        """Request the grid platform cancels the experiment

        Returns
        -------
        str
            Name of the experiment if it was successfully cancelled or had
            previously reached a terminal status ("CANCELLED", "FAILED", "COMPLETED").
        """
        # do not perform POST if we know that we don't have to
        cancel_experiment(self._exp_id)
        if self._last_status not in env.TERMINAL_STATES:
            self._last_status = "CANCELLED"
        return self.name

    def build_logs(self, n_lines: int = 200) -> Iterable[str]:
        """Request the build logs for this experiment from the grid platform.

        Parameters
        ----------
        n_lines
            Max number of lines to return. By default, 200.

        Yields
        -------
        str
            every return is a single line of the build log output;
            sorted by order of time, oldest log is at index 0,
            latest log is at the end of the list.
        """
        status = self.status()
        if status == 'PENDING':
            return []
        elif status in env.TERMINAL_STATES:
            logs = experiment_archived_build_logs(exp_id=self.id)
        else:
            logs = experiment_live_build_logs(exp_id=self.id, limit=n_lines)

        for log in logs:
            ts = datetime.fromisoformat(log['timestamp'])
            yield f"[{ts}] [{log['message'].rstrip()}]\n"

    def logs(self, n_lines: int = 200) -> Iterable[str]:
        """Request the stdout logs for this experiment from the grid platform.

        Parameters
        ----------
        n_lines
            Max number of lines to return. By default, 200.

        Yields
        -------
        str
            every return is a single line of the build log output;
            sorted by order of time, oldest log is at index 0,
            latest log is at the end of the list.
        """
        status = self.status()
        if status == 'PENDING':
            return []
        elif status in env.TERMINAL_STATES:
            logs = experiment_archived_logs(exp_id=self.id)
        else:
            logs = experiment_live_logs(exp_id=self.id, n_lines=n_lines)

        for log in logs:
            ts = datetime.fromisoformat(log['timestamp'])
            yield f"[{ts}] [{log['message'].rstrip()}]\n"

    # def artifacts(self, p: Union[str, Path]) -> List[str]:
    #     """Download experiment artifacts to the specified directory path.
    #
    #     TODO(rlizzo): This entire workflow should allow for iterating over
    #                   the the available data files that can be downloaded.
    #                   Maybe make this a property and just return an metrics
    #                   object which implements methods of type
    #                   ``collections.abc.MappingView``.
    #
    #     Parameters
    #     ----------
    #     p
    #         Path to a directory in which to store the resulting artifacts.
    #         This path must exist on the host machine and must be writeable by
    #         the PID/user executing this program.
    #
    #     Returns
    #     -------
    #     List[str]
    #         Paths to files which have been written on disk.
    #     """
    #     raise NotImplementedError

    # def metrics(self):
    #     """Download metrics
    #
    #     TODO(rlizzo): This entire workflow should allow for iterating over the
    #                   available metrics. Maybe make this a property and just
    #                   return an metrics object which implements methods of type
    #                   ``collections.abc.MappingView``.
    #     """
    #     raise NotImplementedError



from __future__ import absolute_import

# import apis into api package
from grid.openapi.api.auth_service_api import AuthServiceApi
from grid.openapi.api.cluster_service_api import ClusterServiceApi
from grid.openapi.api.saml_organizations_service_api import SAMLOrganizationsServiceApi
from grid.openapi.api.session_service_api import SessionServiceApi

# flake8: noqa



from grid.cli.observables.base import BaseObservable
from grid.cli.observables.experiment import Experiment
from grid.cli.observables.interactive_node import InteractiveNode
from grid.cli.observables.run import Run

__all__ = ['BaseObservable', 'Experiment', 'InteractiveNode', 'Run']



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1Resources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {'cpu': 'str', 'extra': 'dict(str, str)', 'gpu': 'str', 'storage_gb': 'str'}

    attribute_map = {'cpu': 'cpu', 'extra': 'extra', 'gpu': 'gpu', 'storage_gb': 'storageGb'}

    def __init__(self, cpu=None, extra=None, gpu=None, storage_gb=None, _configuration=None):  # noqa: E501
        """V1Resources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu = None
        self._extra = None
        self._gpu = None
        self._storage_gb = None
        self.discriminator = None

        if cpu is not None:
            self.cpu = cpu
        if extra is not None:
            self.extra = extra
        if gpu is not None:
            self.gpu = gpu
        if storage_gb is not None:
            self.storage_gb = storage_gb

    @property
    def cpu(self):
        """Gets the cpu of this V1Resources.  # noqa: E501


        :return: The cpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """Sets the cpu of this V1Resources.


        :param cpu: The cpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._cpu = cpu

    @property
    def extra(self):
        """Gets the extra of this V1Resources.  # noqa: E501


        :return: The extra of this V1Resources.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extra

    @extra.setter
    def extra(self, extra):
        """Sets the extra of this V1Resources.


        :param extra: The extra of this V1Resources.  # noqa: E501
        :type: dict(str, str)
        """

        self._extra = extra

    @property
    def gpu(self):
        """Gets the gpu of this V1Resources.  # noqa: E501


        :return: The gpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu):
        """Sets the gpu of this V1Resources.


        :param gpu: The gpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._gpu = gpu

    @property
    def storage_gb(self):
        """Gets the storage_gb of this V1Resources.  # noqa: E501


        :return: The storage_gb of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._storage_gb

    @storage_gb.setter
    def storage_gb(self, storage_gb):
        """Sets the storage_gb of this V1Resources.


        :param storage_gb: The storage_gb of this V1Resources.  # noqa: E501
        :type: str
        """

        self._storage_gb = storage_gb

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1Resources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Resources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Resources):
            return True

        return self.to_dict() != other.to_dict()



from typing import List

import click

from grid.cli import rich_click
from grid.cli.client import Grid
from grid.cli.utilities import is_experiment


@rich_click.group()
def stop():
    """Stop Runs, Experiments, or Sessions."""
    pass


@stop.command()
@rich_click.argument('experiment_ids', type=str, required=True, nargs=-1, help="The experiment IDs to stop.")
def experiment(experiment_ids: List[str]):
    """Stop one or more experiments."""
    client = Grid()
    for experiment in experiment_ids:
        if is_experiment(experiment):
            client.cancel(experiment_name=experiment)
        else:
            raise click.ClickException(f"Could not find experiment: {experiment}.")


@stop.command()
@rich_click.argument('run_ids', type=str, required=True, nargs=-1, help="The run IDs to stop.")
def run(run_ids: List[str]):
    """Stop one or more runs."""
    client = Grid()
    for run in run_ids:
        if client.is_run(run_name=run):
            client.cancel(run_name=run)
        else:
            raise click.ClickException(f"Could not find run: {run}.")


@stop.command()
@rich_click.argument('session_ids', type=str, required=True, nargs=-1, help="The session IDs to stop.")
def session(session_ids: List[str]):
    """Stop one or more sessions."""
    client = Grid()
    for session in session_ids:
        if client.is_interactive_node(interactive_node_name=session):
            client.delete_interactive_node(interactive_node_name=session)
        else:
            raise click.ClickException(f"Could not find session: {session}.")



"""TODO(rlizzo): THIS FILE IS PART OF PROJECT FEYNMAN

Create tar file from folder
"""
from dataclasses import dataclass
import math
import os
import subprocess
import tarfile
from typing import Optional, Tuple

import click

MAX_SPLIT_COUNT = 999


def get_dir_size_and_count(source_dir: str, prefix: Optional[str] = None) -> Tuple[int, int]:
    """
    Get size and file count of a directory

    Parameters
    ----------
    source_dir: str
        Directory path

    Returns
    -------
    Tuple[int, int]
        Size in megabytes and file count
    """
    size = 0
    count = 0
    for root, _, files in os.walk(source_dir, topdown=True):
        for f in files:
            if prefix and not f.startswith(prefix):
                continue

            full_path = os.path.join(root, f)
            size += os.path.getsize(full_path)
            count += 1

    return (size, count)


@dataclass
class TarResults:
    """
    This class holds the results of running tar_path.

    Attributes
    ----------
    before_size: int
        The total size of the original directory files in bytes
    after_size: int
        The total size of the compressed and tarred split files in bytes
    """
    before_size: int
    after_size: int


def get_split_size(
    total_size: int, minimum_split_size: int = 1024 * 1000 * 20, max_split_count: int = MAX_SPLIT_COUNT
) -> int:
    """
    Calculate the split size we should use to split the multipart upload of an object to a bucket.  We are limited
    to 1000 max parts as the way we are using ListMultipartUploads.
    More info
        https://github.com/gridai/grid/pull/5267
        https://docs.aws.amazon.com/AmazonS3/latest/userguide/mpuoverview.html#mpu-process
        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html
        https://github.com/psf/requests/issues/2717#issuecomment-724725392 Python or requests has a limit of 2**31 bytes for a single file upload.

    Parameters
    ----------
    minimum_split_size: int
        The minimum split size to use
    max_split_count: int
        The maximum split count
    total_size: int
        Total size of the file to split

    Returns
    -------
    int
        Split size
    """
    max_size = max_split_count * (1 << 31)  # max size per part limited by Requests or urllib as shown in ref above
    if total_size > max_size:
        raise click.ClickException(
            f"The size of the datastore to be uploaded is bigger than our {max_size/(1 << 40):.2f} TBytes limit"
        )

    split_size = minimum_split_size
    split_count = math.ceil(total_size / split_size)
    if split_count > max_split_count:
        # Adjust the split size based on max split count
        split_size = math.ceil(total_size / max_split_count)

    return split_size


def tar_path(source_path: str, target_file: str, compression: bool = False) -> TarResults:
    """
    Create tar from directory using `tar`

    Parameters
    ----------
    source_path: str
        Source directory or file
    target_file
        Target tar file
    compression: bool, default False
        Enable compression, which is disabled by default.

    Returns
    -------
    TarResults
        Results that holds file counts and sizes
    """
    if os.path.isdir(source_path):
        before_size, _ = get_dir_size_and_count(source_path)
    else:
        before_size = os.path.getsize(source_path)

    try:
        _tar_path_subprocess(source_path, target_file, compression)
    except subprocess.CalledProcessError:
        _tar_path_python(source_path, target_file, compression)

    after_size = os.stat(target_file).st_size
    return TarResults(before_size=before_size, after_size=after_size)


def _tar_path_python(source_path: str, target_file: str, compression: bool = False) -> None:
    """
    Create tar from directory using `python`

    Parameters
    ----------
    source_path: str
        Source directory or file
    target_file
        Target tar file
    compression: bool, default False
        Enable compression, which is disabled by default.
    """
    file_mode = "w:gz" if compression else "w:"

    with tarfile.open(target_file, file_mode) as tar:
        if os.path.isdir(source_path):
            tar.add(str(source_path), arcname=".")
        elif os.path.isfile(source_path):
            file_info = tarfile.TarInfo(os.path.basename(str(source_path)))
            tar.addfile(file_info, open(source_path))


def _tar_path_subprocess(source_path: str, target_file: str, compression: bool = False) -> None:
    """
    Create tar from directory using `tar`

    Parameters
    ----------
    source_path: str
        Source directory or file
    target_file
        Target tar file
    compression: bool, default False
        Enable compression, which is disabled by default.
    """
    # Only add compression when users explicitly request it.
    # We do this because it takes too long to compress
    # large datastores.
    tar_flags = '-cvf'
    if compression:
        tar_flags = '-zcvf'
    if os.path.isdir(source_path):
        command = f"tar -C {source_path} {tar_flags} {target_file} ./"
    else:
        abs_path = os.path.abspath(source_path)
        parent_dir = os.path.dirname(abs_path)
        base_name = os.path.basename(abs_path)
        command = f"tar -C {parent_dir} {tar_flags} {target_file} {base_name}"

    subprocess.check_call(
        command,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
        shell=True,
        env={
            "GZIP": "-9",
            "COPYFILE_DISABLE": "1"
        }
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import experiment_pb2 as grid_dot_v1_dot_experiment__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/run.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x11grid/v1/run.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x18grid/v1/experiment.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x86\x01\n\x03Run\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12$\n\x04spec\x18\x02 \x01(\x0b\x32\x10.grid.v1.RunSpecR\x04spec\x12*\n\x06status\x18\x03 \x01(\x0b\x32\x12.grid.v1.RunStatusR\x06status\"\xd9\x01\n\x07RunSpec\x12/\n\x08template\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\x08template\x12:\n\tgenerator\x18\x02 \x01(\x0b\x32\x1c.grid.v1.ExperimentGeneratorR\tgenerator\x12\x36\n\rdesired_state\x18\x03 \x01(\x0e\x32\x11.grid.v1.RunStateR\x0c\x64\x65siredState\x12)\n\x10pause_automation\x18\x04 \x01(\x08R\x0fpauseAutomation\"\xcc\x01\n\x13\x45xperimentGenerator\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x36\n\x0bgrid_search\x18\x02 \x01(\x0b\x32\x13.grid.v1.GridSearchH\x00R\ngridSearch\x12<\n\rrandom_search\x18\x03 \x01(\x0b\x32\x15.grid.v1.RandomSearchH\x00R\x0crandomSearchB\x0b\n\tgenerator\"\xcd\x01\n\x05Param\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x32\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x32\n\x08\x64\x65screte\x18\x03 \x01(\x0b\x32\x14.grid.v1.DiscreteSetH\x00R\x08\x64\x65screte\x12\x38\n\x07uniform\x18\x04 \x01(\x0b\x32\x1c.grid.v1.UniformDistributionH\x00R\x07uniformB\x0e\n\x0c\x64istribution\"%\n\x0b\x44iscreteSet\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"Z\n\x13UniformDistribution\x12\x10\n\x03min\x18\x01 \x01(\x02R\x03min\x12\x10\n\x03max\x18\x02 \x01(\x02R\x03max\x12\x1f\n\x0bnum_samples\x18\x03 \x01(\x05R\nnumSamples\"4\n\nGridSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\"U\n\x0cRandomSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\x12\x1d\n\nnum_trials\x18\x02 \x01(\x03R\tnumTrials\"\xda\x01\n\tRunStatus\x12\x41\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32\x1f.grid.v1.ExperimentSummaryEntryR\x0b\x65xperiments\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12\x45\n\x10\x66inish_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inishTimestamp\"\x7f\n\x16\x45xperimentSummaryEntry\x12\x14\n\x05\x63ount\x18\x01 \x01(\x04R\x05\x63ount\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32\x18.grid.v1.ExperimentStateR\x06status\x12\x1d\n\ncluster_id\x18\x03 \x01(\tR\tclusterId*\xc7\x01\n\x08RunState\x12\x19\n\x15RUN_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11RUN_STATE_PENDING\x10\x01\x12\x14\n\x10RUN_STATE_QUEUED\x10\x02\x12\x15\n\x11RUN_STATE_RUNNING\x10\x03\x12\x17\n\x13RUN_STATE_COMPLETED\x10\x04\x12\x14\n\x10RUN_STATE_FAILED\x10\x05\x12\x16\n\x12RUN_STATE_CANCELED\x10\x06\x12\x15\n\x11RUN_STATE_DELETED\x10\x07\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_experiment__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_RUNSTATE = _descriptor.EnumDescriptor(
    name='RunState',
    full_name='grid.v1.RunState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_PENDING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_QUEUED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_RUNNING',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_COMPLETED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_FAILED',
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_CANCELED',
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RUN_STATE_DELETED',
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1535,
    serialized_end=1734,
)
_sym_db.RegisterEnumDescriptor(_RUNSTATE)

RunState = enum_type_wrapper.EnumTypeWrapper(_RUNSTATE)
RUN_STATE_UNSPECIFIED = 0
RUN_STATE_PENDING = 1
RUN_STATE_QUEUED = 2
RUN_STATE_RUNNING = 3
RUN_STATE_COMPLETED = 4
RUN_STATE_FAILED = 5
RUN_STATE_CANCELED = 6
RUN_STATE_DELETED = 7

_RUN = _descriptor.Descriptor(
    name='Run',
    full_name='grid.v1.Run',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Run.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Run.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Run.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=141,
    serialized_end=275,
)

_RUNSPEC = _descriptor.Descriptor(
    name='RunSpec',
    full_name='grid.v1.RunSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='template',
            full_name='grid.v1.RunSpec.template',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='template',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='generator',
            full_name='grid.v1.RunSpec.generator',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='generator',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.RunSpec.desired_state',
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='pause_automation',
            full_name='grid.v1.RunSpec.pause_automation',
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='pauseAutomation',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=278,
    serialized_end=495,
)

_EXPERIMENTGENERATOR = _descriptor.Descriptor(
    name='ExperimentGenerator',
    full_name='grid.v1.ExperimentGenerator',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ExperimentGenerator.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='grid_search',
            full_name='grid.v1.ExperimentGenerator.grid_search',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='gridSearch',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='random_search',
            full_name='grid.v1.ExperimentGenerator.random_search',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='randomSearch',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='generator',
            full_name='grid.v1.ExperimentGenerator.generator',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=498,
    serialized_end=702,
)

_PARAM = _descriptor.Descriptor(
    name='Param',
    full_name='grid.v1.Param',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='name',
            full_name='grid.v1.Param.name',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='name',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.Param.external',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='descrete',
            full_name='grid.v1.Param.descrete',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='descrete',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='uniform',
            full_name='grid.v1.Param.uniform',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='uniform',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='distribution',
            full_name='grid.v1.Param.distribution',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=705,
    serialized_end=910,
)

_DISCRETESET = _descriptor.Descriptor(
    name='DiscreteSet',
    full_name='grid.v1.DiscreteSet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='values',
            full_name='grid.v1.DiscreteSet.values',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='values',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=912,
    serialized_end=949,
)

_UNIFORMDISTRIBUTION = _descriptor.Descriptor(
    name='UniformDistribution',
    full_name='grid.v1.UniformDistribution',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='min',
            full_name='grid.v1.UniformDistribution.min',
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='min',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='max',
            full_name='grid.v1.UniformDistribution.max',
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='max',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='num_samples',
            full_name='grid.v1.UniformDistribution.num_samples',
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='numSamples',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=951,
    serialized_end=1041,
)

_GRIDSEARCH = _descriptor.Descriptor(
    name='GridSearch',
    full_name='grid.v1.GridSearch',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='params',
            full_name='grid.v1.GridSearch.params',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='params',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1043,
    serialized_end=1095,
)

_RANDOMSEARCH = _descriptor.Descriptor(
    name='RandomSearch',
    full_name='grid.v1.RandomSearch',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='params',
            full_name='grid.v1.RandomSearch.params',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='params',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='num_trials',
            full_name='grid.v1.RandomSearch.num_trials',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='numTrials',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1097,
    serialized_end=1182,
)

_RUNSTATUS = _descriptor.Descriptor(
    name='RunStatus',
    full_name='grid.v1.RunStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiments',
            full_name='grid.v1.RunStatus.experiments',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiments',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.RunStatus.start_timestamp',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='finish_timestamp',
            full_name='grid.v1.RunStatus.finish_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='finishTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1185,
    serialized_end=1403,
)

_EXPERIMENTSUMMARYENTRY = _descriptor.Descriptor(
    name='ExperimentSummaryEntry',
    full_name='grid.v1.ExperimentSummaryEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='count',
            full_name='grid.v1.ExperimentSummaryEntry.count',
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='count',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.ExperimentSummaryEntry.status',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ExperimentSummaryEntry.cluster_id',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1405,
    serialized_end=1532,
)

_RUN.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_RUN.fields_by_name['spec'].message_type = _RUNSPEC
_RUN.fields_by_name['status'].message_type = _RUNSTATUS
_RUNSPEC.fields_by_name['template'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_RUNSPEC.fields_by_name['generator'].message_type = _EXPERIMENTGENERATOR
_RUNSPEC.fields_by_name['desired_state'].enum_type = _RUNSTATE
_EXPERIMENTGENERATOR.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].message_type = _GRIDSEARCH
_EXPERIMENTGENERATOR.fields_by_name['random_search'].message_type = _RANDOMSEARCH
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(_EXPERIMENTGENERATOR.fields_by_name['external'])
_EXPERIMENTGENERATOR.fields_by_name['external'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(_EXPERIMENTGENERATOR.fields_by_name['grid_search'])
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(_EXPERIMENTGENERATOR.fields_by_name['random_search'])
_EXPERIMENTGENERATOR.fields_by_name['random_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_PARAM.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PARAM.fields_by_name['descrete'].message_type = _DISCRETESET
_PARAM.fields_by_name['uniform'].message_type = _UNIFORMDISTRIBUTION
_PARAM.oneofs_by_name['distribution'].fields.append(_PARAM.fields_by_name['external'])
_PARAM.fields_by_name['external'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(_PARAM.fields_by_name['descrete'])
_PARAM.fields_by_name['descrete'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(_PARAM.fields_by_name['uniform'])
_PARAM.fields_by_name['uniform'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_GRIDSEARCH.fields_by_name['params'].message_type = _PARAM
_RANDOMSEARCH.fields_by_name['params'].message_type = _PARAM
_RUNSTATUS.fields_by_name['experiments'].message_type = _EXPERIMENTSUMMARYENTRY
_RUNSTATUS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNSTATUS.fields_by_name['finish_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENTSUMMARYENTRY.fields_by_name['status'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
DESCRIPTOR.message_types_by_name['Run'] = _RUN
DESCRIPTOR.message_types_by_name['RunSpec'] = _RUNSPEC
DESCRIPTOR.message_types_by_name['ExperimentGenerator'] = _EXPERIMENTGENERATOR
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['DiscreteSet'] = _DISCRETESET
DESCRIPTOR.message_types_by_name['UniformDistribution'] = _UNIFORMDISTRIBUTION
DESCRIPTOR.message_types_by_name['GridSearch'] = _GRIDSEARCH
DESCRIPTOR.message_types_by_name['RandomSearch'] = _RANDOMSEARCH
DESCRIPTOR.message_types_by_name['RunStatus'] = _RUNSTATUS
DESCRIPTOR.message_types_by_name['ExperimentSummaryEntry'] = _EXPERIMENTSUMMARYENTRY
DESCRIPTOR.enum_types_by_name['RunState'] = _RUNSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Run = _reflection.GeneratedProtocolMessageType(
    'Run',
    (_message.Message, ),
    {
        'DESCRIPTOR': _RUN,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Run)
    }
)
_sym_db.RegisterMessage(Run)

RunSpec = _reflection.GeneratedProtocolMessageType(
    'RunSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _RUNSPEC,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.RunSpec)
    }
)
_sym_db.RegisterMessage(RunSpec)

ExperimentGenerator = _reflection.GeneratedProtocolMessageType(
    'ExperimentGenerator',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTGENERATOR,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentGenerator)
    }
)
_sym_db.RegisterMessage(ExperimentGenerator)

Param = _reflection.GeneratedProtocolMessageType(
    'Param',
    (_message.Message, ),
    {
        'DESCRIPTOR': _PARAM,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Param)
    }
)
_sym_db.RegisterMessage(Param)

DiscreteSet = _reflection.GeneratedProtocolMessageType(
    'DiscreteSet',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DISCRETESET,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DiscreteSet)
    }
)
_sym_db.RegisterMessage(DiscreteSet)

UniformDistribution = _reflection.GeneratedProtocolMessageType(
    'UniformDistribution',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UNIFORMDISTRIBUTION,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UniformDistribution)
    }
)
_sym_db.RegisterMessage(UniformDistribution)

GridSearch = _reflection.GeneratedProtocolMessageType(
    'GridSearch',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GRIDSEARCH,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GridSearch)
    }
)
_sym_db.RegisterMessage(GridSearch)

RandomSearch = _reflection.GeneratedProtocolMessageType(
    'RandomSearch',
    (_message.Message, ),
    {
        'DESCRIPTOR': _RANDOMSEARCH,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.RandomSearch)
    }
)
_sym_db.RegisterMessage(RandomSearch)

RunStatus = _reflection.GeneratedProtocolMessageType(
    'RunStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _RUNSTATUS,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.RunStatus)
    }
)
_sym_db.RegisterMessage(RunStatus)

ExperimentSummaryEntry = _reflection.GeneratedProtocolMessageType(
    'ExperimentSummaryEntry',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSUMMARYENTRY,
        '__module__': 'grid.v1.run_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSummaryEntry)
    }
)
_sym_db.RegisterMessage(ExperimentSummaryEntry)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Original solution from
#
#      https://github.com/navdeep-G/setup.py
#
#  Original license notice:
#
#  Copyright 2020 navdeep-G & GitHub contributors
#
#  Permission is hereby granted, free of charge, to any
#  person obtaining a copy of this software and associated
#  documentation files (the "Software"), to deal in the
#  Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute,
#  sublicense, and/or sell copies of the Software, and to
#  permit persons to whom the Software is furnished to do so,
#  subject to the following conditions:
#
#  The above copyright notice and this permission notice shall
#  be included in all copies or substantial portions of the Software.

#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
#  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
#  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
#  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

#  NOTE: To use the 'upload' functionality of this file, you must:
#    $ pip install twine

import os
from pathlib import Path
from shutil import rmtree
import sys

from setuptools import Command, find_packages, setup
from setuptools.command.install import install

from grid.cli.utilities import check_environment_variables, GCPStorage, install_autocomplete
from grid.metadata import __package_name__, __version__

#   Package meta-data.
NAME = 'grid'
PACKAGE_NAME = __package_name__
DESCRIPTION = 'Grid Python SDK.'
URL = 'https://grid.ai'
EMAIL = 'grid-eng@grid.ai'
AUTHOR = 'Grid AI Engineering'
REQUIRES_PYTHON = '>=3.7.0'
VERSION = os.getenv("VERSION", __version__)

#  What packages are required for this module to be executed?
REQUIRED = []
with open('requirements.txt') as f:
    for line in f.readlines():
        REQUIRED.append(line.replace('\n', ''))

SETUP_REQUIRES = [
    'setuptools>=40.0',
    'wheel>=0.30',
]

#  What packages are optional?
EXTRAS = {}

#  The rest you shouldn't have to touch too much :)
#  ------------------------------------------------
#  Except, perhaps the License and Trove Classifiers!
#  If you do change the License, remember to
#  the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

#  Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, NAME, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION


def upload_gcp_wheel(gcp_storage, version, bucket_name, blob_path):
    """
    Uploads lightning wheel to it's designated GCP bucket.
    """
    whl_exists = False
    for file in os.listdir('dist'):
        if '.whl' in file:
            wheel = file
            whl_exists = True

    if whl_exists:
        lastest_path = Path(blob_path) / "latest" / wheel
        version_path = Path(blob_path) / version / wheel

        # delete existing object in "latest" directory
        gcp_storage.delete_blobs(bucket_name=bucket_name, prefix=f'{blob_path}/latest/')

        gcp_storage.upload_blob(
            bucket_name=bucket_name, source_file_name=f'dist/{wheel}', destination_blob_name=lastest_path
        )
        gcp_storage.upload_blob(
            bucket_name=bucket_name, source_file_name=f'dist/{wheel}', destination_blob_name=version_path
        )
    else:
        raise ValueError("You did not build a wheel for this project.")


class UploadCommandPyPi(Command):
    """Support setup.py upload-pypi."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        # skipcq: BAN-B605
        os.system('{0} setup.py sdist bdist_wheel'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        # skipcq: BAN-B605
        os.system('twine upload dist/*')

        sys.exit()


class UploadCommandGCP(Command):
    """Support setup.py upload-gcp."""

    description = 'Build and publish the package to GCP.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Checking environment variables…')
        check_environment_variables(['GOOGLE_APPLICATION_CREDENTIALS', 'GCP_GRID_BUCKET', 'GCP_BLOB_PATH'])

        self.status('Building Source and Wheel (universal) distribution…')
        # skipcq: BAN-B605
        os.system('{0} setup.py sdist bdist_wheel'.format(sys.executable))

        self.status('Uploading to GCP…')
        gcp_storage = GCPStorage()
        upload_gcp_wheel(
            gcp_storage=gcp_storage,
            version=VERSION,
            bucket_name=os.getenv('GCP_GRID_BUCKET'),
            blob_path=os.getenv('GCP_BLOB_PATH')
        )

        sys.exit()


class Install(install):
    """
    Override setup tools `install` command to do any pre/post install logic.
    """
    def run(self):
        install.run(self)
        install_autocomplete()


#  Where the magic happens:
setup(
    name=PACKAGE_NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    author=AUTHOR,
    author_email=EMAIL,
    setup_requires=SETUP_REQUIRES,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=('tests', 'tests.*')),
    entry_points={
        'console_scripts': ['grid=grid.cli.__main__:main'],
    },
    long_description="Grid AI Command Line Interface",
    long_description_content_type="text/x-rst",
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    #  $ setup.py publish support.
    cmdclass={
        'pypi': UploadCommandPyPi,
        'gcp': UploadCommandGCP,
        'install': Install
    },
)



from enum import Enum


class WorkflowType(Enum):
    """
    Type of workflow in place. This is useful to differentiate
    between the script and blueprint workflows.
    """
    SCRIPT = 'script'
    BLUEPRINT = 'blueprint'


class ObservableType(Enum):
    """
    Observable types of objects from Grid. These objects can be followed
    with status.
    """
    CLUSTER = 'cluster'
    RUN = 'run'
    EXPERIMENT = 'experiment'
    INTERACTIVE = 'interactive'



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/sshpublickey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/sshpublickey.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1agrid/v1/sshpublickey.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\"\xaa\x01\n\x0cSSHPublicKey\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\x12\x19\n\x08key_type\x18\x03 \x01(\tR\x07keyType\x12\x18\n\x07\x63omment\x18\x04 \x01(\tR\x07\x63omment\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userIdB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
    ]
)

_SSHPUBLICKEY = _descriptor.Descriptor(
    name='SSHPublicKey',
    full_name='grid.v1.SSHPublicKey',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.SSHPublicKey.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='public_key',
            full_name='grid.v1.SSHPublicKey.public_key',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='publicKey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='key_type',
            full_name='grid.v1.SSHPublicKey.key_type',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='keyType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='comment',
            full_name='grid.v1.SSHPublicKey.comment',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='comment',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.SSHPublicKey.user_id',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=64,
    serialized_end=234,
)

_SSHPUBLICKEY.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
DESCRIPTOR.message_types_by_name['SSHPublicKey'] = _SSHPUBLICKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SSHPublicKey = _reflection.GeneratedProtocolMessageType(
    'SSHPublicKey',
    (_message.Message, ),
    {
        'DESCRIPTOR': _SSHPUBLICKEY,
        '__module__': 'grid.v1.sshpublickey_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.SSHPublicKey)
    }
)
_sym_db.RegisterMessage(SSHPublicKey)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/sshpublickey_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import sshpublickey_pb2 as grid_dot_v1_dot_sshpublickey__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/sshpublickey_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\"grid/v1/sshpublickey_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x1agrid/v1/sshpublickey.proto\"V\n\x19\x43reateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x43reateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"(\n\x16GetSSHPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"T\n\x17GetSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\x9b\x01\n\x18ListSSHPublicKeysRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xa8\x01\n\x19ListSSHPublicKeysResponse\x12\x39\n\x0csshpublickey\x18\x01 \x03(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"V\n\x19UpdateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1aUpdateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\\\n\x1fUpdateSSHPublicKeyStatusRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"]\n UpdateSSHPublicKeyStatusResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"V\n\x19\x44\x65leteSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x44\x65leteSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"u\n\x19WatchSSHPublicKeysRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xaf\x01\n\x1aWatchSSHPublicKeysResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x39\n\x0csshpublickey\x18\x03 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey2\xc0\x05\n\x13SSHPublicKeyService\x12_\n\x12\x43reateSSHPublicKey\x12\".grid.v1.CreateSSHPublicKeyRequest\x1a#.grid.v1.CreateSSHPublicKeyResponse\"\x00\x12V\n\x0fGetSSHPublicKey\x12\x1f.grid.v1.GetSSHPublicKeyRequest\x1a .grid.v1.GetSSHPublicKeyResponse\"\x00\x12\\\n\x11ListSSHPublicKeys\x12!.grid.v1.ListSSHPublicKeysRequest\x1a\".grid.v1.ListSSHPublicKeysResponse\"\x00\x12_\n\x12UpdateSSHPublicKey\x12\".grid.v1.UpdateSSHPublicKeyRequest\x1a#.grid.v1.UpdateSSHPublicKeyResponse\"\x00\x12o\n\x18UpdateSSHPublicKeyStatus\x12(.grid.v1.UpdateSSHPublicKeyStatusRequest\x1a).grid.v1.UpdateSSHPublicKeyStatusResponse\x12_\n\x12\x44\x65leteSSHPublicKey\x12\".grid.v1.DeleteSSHPublicKeyRequest\x1a#.grid.v1.DeleteSSHPublicKeyResponse\"\x00\x12_\n\x12WatchSSHPublicKeys\x12\".grid.v1.WatchSSHPublicKeysRequest\x1a#.grid.v1.WatchSSHPublicKeysResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_sshpublickey__pb2.DESCRIPTOR,
    ]
)

_CREATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name='CreateSSHPublicKeyRequest',
    full_name='grid.v1.CreateSSHPublicKeyRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.CreateSSHPublicKeyRequest.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=129,
    serialized_end=215,
)

_CREATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
    name='CreateSSHPublicKeyResponse',
    full_name='grid.v1.CreateSSHPublicKeyResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.CreateSSHPublicKeyResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=217,
    serialized_end=304,
)

_GETSSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name='GetSSHPublicKeyRequest',
    full_name='grid.v1.GetSSHPublicKeyRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetSSHPublicKeyRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=306,
    serialized_end=346,
)

_GETSSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
    name='GetSSHPublicKeyResponse',
    full_name='grid.v1.GetSSHPublicKeyResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.GetSSHPublicKeyResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=348,
    serialized_end=432,
)

_LISTSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
    name='ListSSHPublicKeysRequest',
    full_name='grid.v1.ListSSHPublicKeysRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListSSHPublicKeysRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListSSHPublicKeysRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListSSHPublicKeysRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListSSHPublicKeysRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=435,
    serialized_end=590,
)

_LISTSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
    name='ListSSHPublicKeysResponse',
    full_name='grid.v1.ListSSHPublicKeysResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.ListSSHPublicKeysResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListSSHPublicKeysResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListSSHPublicKeysResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=593,
    serialized_end=761,
)

_UPDATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name='UpdateSSHPublicKeyRequest',
    full_name='grid.v1.UpdateSSHPublicKeyRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.UpdateSSHPublicKeyRequest.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=763,
    serialized_end=849,
)

_UPDATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
    name='UpdateSSHPublicKeyResponse',
    full_name='grid.v1.UpdateSSHPublicKeyResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.UpdateSSHPublicKeyResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=851,
    serialized_end=938,
)

_UPDATESSHPUBLICKEYSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateSSHPublicKeyStatusRequest',
    full_name='grid.v1.UpdateSSHPublicKeyStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.UpdateSSHPublicKeyStatusRequest.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=940,
    serialized_end=1032,
)

_UPDATESSHPUBLICKEYSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateSSHPublicKeyStatusResponse',
    full_name='grid.v1.UpdateSSHPublicKeyStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.UpdateSSHPublicKeyStatusResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1034,
    serialized_end=1127,
)

_DELETESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name='DeleteSSHPublicKeyRequest',
    full_name='grid.v1.DeleteSSHPublicKeyRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.DeleteSSHPublicKeyRequest.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1129,
    serialized_end=1215,
)

_DELETESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
    name='DeleteSSHPublicKeyResponse',
    full_name='grid.v1.DeleteSSHPublicKeyResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.DeleteSSHPublicKeyResponse.sshpublickey',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1217,
    serialized_end=1304,
)

_WATCHSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
    name='WatchSSHPublicKeysRequest',
    full_name='grid.v1.WatchSSHPublicKeysRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchSSHPublicKeysRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchSSHPublicKeysRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchSSHPublicKeysRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1306,
    serialized_end=1423,
)

_WATCHSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
    name='WatchSSHPublicKeysResponse',
    full_name='grid.v1.WatchSSHPublicKeysResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchSSHPublicKeysResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchSSHPublicKeysResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='sshpublickey',
            full_name='grid.v1.WatchSSHPublicKeysResponse.sshpublickey',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshpublickey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1426,
    serialized_end=1601,
)

_CREATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_CREATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'
                                           ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_GETSSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_LISTSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'
                                           ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSREQUEST.fields_by_name['sshpublickey'
                                                ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSRESPONSE.fields_by_name['sshpublickey'
                                                 ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'
                                           ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'
                                           ].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyRequest'] = _CREATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyResponse'] = _CREATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyRequest'] = _GETSSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyResponse'] = _GETSSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysRequest'] = _LISTSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysResponse'] = _LISTSSHPUBLICKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyRequest'] = _UPDATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyResponse'] = _UPDATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusRequest'] = _UPDATESSHPUBLICKEYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusResponse'] = _UPDATESSHPUBLICKEYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyRequest'] = _DELETESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyResponse'] = _DELETESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysRequest'] = _WATCHSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysResponse'] = _WATCHSSHPUBLICKEYSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    'CreateSSHPublicKeyRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATESSHPUBLICKEYREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyRequest)
    }
)
_sym_db.RegisterMessage(CreateSSHPublicKeyRequest)

CreateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType(
    'CreateSSHPublicKeyResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATESSHPUBLICKEYRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyResponse)
    }
)
_sym_db.RegisterMessage(CreateSSHPublicKeyResponse)

GetSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    'GetSSHPublicKeyRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSSHPUBLICKEYREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyRequest)
    }
)
_sym_db.RegisterMessage(GetSSHPublicKeyRequest)

GetSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType(
    'GetSSHPublicKeyResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSSHPUBLICKEYRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyResponse)
    }
)
_sym_db.RegisterMessage(GetSSHPublicKeyResponse)

ListSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType(
    'ListSSHPublicKeysRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTSSHPUBLICKEYSREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysRequest)
    }
)
_sym_db.RegisterMessage(ListSSHPublicKeysRequest)

ListSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType(
    'ListSSHPublicKeysResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTSSHPUBLICKEYSRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysResponse)
    }
)
_sym_db.RegisterMessage(ListSSHPublicKeysResponse)

UpdateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateSSHPublicKeyRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESSHPUBLICKEYREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyRequest)
    }
)
_sym_db.RegisterMessage(UpdateSSHPublicKeyRequest)

UpdateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateSSHPublicKeyResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESSHPUBLICKEYRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyResponse)
    }
)
_sym_db.RegisterMessage(UpdateSSHPublicKeyResponse)

UpdateSSHPublicKeyStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateSSHPublicKeyStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESSHPUBLICKEYSTATUSREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusRequest)

UpdateSSHPublicKeyStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateSSHPublicKeyStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESSHPUBLICKEYSTATUSRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusResponse)

DeleteSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteSSHPublicKeyRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETESSHPUBLICKEYREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyRequest)
    }
)
_sym_db.RegisterMessage(DeleteSSHPublicKeyRequest)

DeleteSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteSSHPublicKeyResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETESSHPUBLICKEYRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyResponse)
    }
)
_sym_db.RegisterMessage(DeleteSSHPublicKeyResponse)

WatchSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType(
    'WatchSSHPublicKeysRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHSSHPUBLICKEYSREQUEST,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysRequest)
    }
)
_sym_db.RegisterMessage(WatchSSHPublicKeysRequest)

WatchSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType(
    'WatchSSHPublicKeysResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHSSHPUBLICKEYSRESPONSE,
        '__module__': 'grid.v1.sshpublickey_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysResponse)
    }
)
_sym_db.RegisterMessage(WatchSSHPublicKeysResponse)

DESCRIPTOR._options = None

_SSHPUBLICKEYSERVICE = _descriptor.ServiceDescriptor(
    name='SSHPublicKeyService',
    full_name='grid.v1.SSHPublicKeyService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1604,
    serialized_end=2308,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateSSHPublicKey',
            full_name='grid.v1.SSHPublicKeyService.CreateSSHPublicKey',
            index=0,
            containing_service=None,
            input_type=_CREATESSHPUBLICKEYREQUEST,
            output_type=_CREATESSHPUBLICKEYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetSSHPublicKey',
            full_name='grid.v1.SSHPublicKeyService.GetSSHPublicKey',
            index=1,
            containing_service=None,
            input_type=_GETSSHPUBLICKEYREQUEST,
            output_type=_GETSSHPUBLICKEYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListSSHPublicKeys',
            full_name='grid.v1.SSHPublicKeyService.ListSSHPublicKeys',
            index=2,
            containing_service=None,
            input_type=_LISTSSHPUBLICKEYSREQUEST,
            output_type=_LISTSSHPUBLICKEYSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateSSHPublicKey',
            full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKey',
            index=3,
            containing_service=None,
            input_type=_UPDATESSHPUBLICKEYREQUEST,
            output_type=_UPDATESSHPUBLICKEYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateSSHPublicKeyStatus',
            full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKeyStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATESSHPUBLICKEYSTATUSREQUEST,
            output_type=_UPDATESSHPUBLICKEYSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteSSHPublicKey',
            full_name='grid.v1.SSHPublicKeyService.DeleteSSHPublicKey',
            index=5,
            containing_service=None,
            input_type=_DELETESSHPUBLICKEYREQUEST,
            output_type=_DELETESSHPUBLICKEYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchSSHPublicKeys',
            full_name='grid.v1.SSHPublicKeyService.WatchSSHPublicKeys',
            index=6,
            containing_service=None,
            input_type=_WATCHSSHPUBLICKEYSREQUEST,
            output_type=_WATCHSSHPUBLICKEYSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_SSHPUBLICKEYSERVICE)

DESCRIPTOR.services_by_name['SSHPublicKeyService'] = _SSHPUBLICKEYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/tensorboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/tensorboard.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x19grid/v1/tensorboard.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x9e\x01\n\x0bTensorboard\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.grid.v1.TensorboardSpecR\x04spec\x12\x32\n\x06status\x18\x03 \x01(\x0b\x32\x1a.grid.v1.TensorboardStatusR\x06status\"B\n\x1bTensorboardExperimentConfig\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\"\xd1\x01\n\x0fTensorboardSpec\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x46\n\x0b\x65xperiments\x18\x03 \x03(\x0b\x32$.grid.v1.TensorboardExperimentConfigR\x0b\x65xperiments\x12>\n\rdesired_state\x18\x04 \x01(\x0e\x32\x19.grid.v1.TensorboardStateR\x0c\x64\x65siredState\"\xab\x01\n\x11TensorboardStatus\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12/\n\x05phase\x18\x04 \x01(\x0e\x32\x19.grid.v1.TensorboardStateR\x05phase*\xb0\x01\n\x10TensorboardState\x12!\n\x1dTENSORBOARD_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19TENSORBOARD_STATE_PENDING\x10\x01\x12\x1d\n\x19TENSORBOARD_STATE_RUNNING\x10\x02\x12\x1d\n\x19TENSORBOARD_STATE_DELETED\x10\x03\x12\x1c\n\x18TENSORBOARD_STATE_FAILED\x10\x04\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_TENSORBOARDSTATE = _descriptor.EnumDescriptor(
    name='TensorboardState',
    full_name='grid.v1.TensorboardState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_PENDING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_RUNNING',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_DELETED',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TENSORBOARD_STATE_FAILED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=738,
    serialized_end=914,
)
_sym_db.RegisterEnumDescriptor(_TENSORBOARDSTATE)

TensorboardState = enum_type_wrapper.EnumTypeWrapper(_TENSORBOARDSTATE)
TENSORBOARD_STATE_UNSPECIFIED = 0
TENSORBOARD_STATE_PENDING = 1
TENSORBOARD_STATE_RUNNING = 2
TENSORBOARD_STATE_DELETED = 3
TENSORBOARD_STATE_FAILED = 4

_TENSORBOARD = _descriptor.Descriptor(
    name='Tensorboard',
    full_name='grid.v1.Tensorboard',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Tensorboard.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Tensorboard.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Tensorboard.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=123,
    serialized_end=281,
)

_TENSORBOARDEXPERIMENTCONFIG = _descriptor.Descriptor(
    name='TensorboardExperimentConfig',
    full_name='grid.v1.TensorboardExperimentConfig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='experiment_id',
            full_name='grid.v1.TensorboardExperimentConfig.experiment_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experimentId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=283,
    serialized_end=349,
)

_TENSORBOARDSPEC = _descriptor.Descriptor(
    name='TensorboardSpec',
    full_name='grid.v1.TensorboardSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.TensorboardSpec.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.TensorboardSpec.cluster_id',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='experiments',
            full_name='grid.v1.TensorboardSpec.experiments',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='experiments',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.TensorboardSpec.desired_state',
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=352,
    serialized_end=561,
)

_TENSORBOARDSTATUS = _descriptor.Descriptor(
    name='TensorboardStatus',
    full_name='grid.v1.TensorboardStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='url',
            full_name='grid.v1.TensorboardStatus.url',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='url',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='message',
            full_name='grid.v1.TensorboardStatus.message',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='message',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='updated_at',
            full_name='grid.v1.TensorboardStatus.updated_at',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='updatedAt',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase',
            full_name='grid.v1.TensorboardStatus.phase',
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phase',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=564,
    serialized_end=735,
)

_TENSORBOARD.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_TENSORBOARD.fields_by_name['spec'].message_type = _TENSORBOARDSPEC
_TENSORBOARD.fields_by_name['status'].message_type = _TENSORBOARDSTATUS
_TENSORBOARDSPEC.fields_by_name['experiments'].message_type = _TENSORBOARDEXPERIMENTCONFIG
_TENSORBOARDSPEC.fields_by_name['desired_state'].enum_type = _TENSORBOARDSTATE
_TENSORBOARDSTATUS.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TENSORBOARDSTATUS.fields_by_name['phase'].enum_type = _TENSORBOARDSTATE
DESCRIPTOR.message_types_by_name['Tensorboard'] = _TENSORBOARD
DESCRIPTOR.message_types_by_name['TensorboardExperimentConfig'] = _TENSORBOARDEXPERIMENTCONFIG
DESCRIPTOR.message_types_by_name['TensorboardSpec'] = _TENSORBOARDSPEC
DESCRIPTOR.message_types_by_name['TensorboardStatus'] = _TENSORBOARDSTATUS
DESCRIPTOR.enum_types_by_name['TensorboardState'] = _TENSORBOARDSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tensorboard = _reflection.GeneratedProtocolMessageType(
    'Tensorboard',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARD,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Tensorboard)
    }
)
_sym_db.RegisterMessage(Tensorboard)

TensorboardExperimentConfig = _reflection.GeneratedProtocolMessageType(
    'TensorboardExperimentConfig',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDEXPERIMENTCONFIG,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardExperimentConfig)
    }
)
_sym_db.RegisterMessage(TensorboardExperimentConfig)

TensorboardSpec = _reflection.GeneratedProtocolMessageType(
    'TensorboardSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDSPEC,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardSpec)
    }
)
_sym_db.RegisterMessage(TensorboardSpec)

TensorboardStatus = _reflection.GeneratedProtocolMessageType(
    'TensorboardStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TENSORBOARDSTATUS,
        '__module__': 'grid.v1.tensorboard_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TensorboardStatus)
    }
)
_sym_db.RegisterMessage(TensorboardStatus)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import integrations_pb2 as grid_dot_v1_dot_integrations__pb2


class IntegrationServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.GetGitHubToken = channel.unary_unary(
            '/grid.v1.IntegrationService/GetGitHubToken',
            request_serializer=grid_dot_v1_dot_integrations__pb2.GetGitHubTokenRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_integrations__pb2.GetGitHubTokenResponse.FromString,
        )


class IntegrationServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def GetGitHubToken(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'GetGitHubToken':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetGitHubToken,
            request_deserializer=grid_dot_v1_dot_integrations__pb2.GetGitHubTokenRequest.FromString,
            response_serializer=grid_dot_v1_dot_integrations__pb2.GetGitHubTokenResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.IntegrationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
